@@ -5,7 +5,7 @@
 # Attribution is requested but is not required.
 #
 # PLEASE NOTE that the above applies to THIS FILE ONLY.  Other files in the
-# same distribution or other collection may have more restrictive terms.
+# same distribution or in other collections may have more restrictive terms.
 
 # Common setup stuff, not specifically for test cases.
 # This file is intended to be identical in all my module distributions.
@@ -19,7 +19,25 @@ BEGIN {
   $default_pragmas = ($^H//"u").":".hash2str(\%^H);
 }
 
-use strict; use warnings  FATAL => 'all'; use feature qw/say state/;
+use strict;
+
+# Do not fatalize decode warnings (under category 'utf8') because various smokers
+# can have restrictive stdout encodings.
+use warnings  FATAL => 'all';
+use warnings  NONFATAL => qw(
+        utf8
+        exec
+        recursion
+        internal
+        malloc
+        newline
+        experimental
+        deprecated
+        portable
+      );
+#no warnings "once";
+
+use feature qw/say state/;
 
 require Exporter;
 use parent 'Exporter';
@@ -81,8 +99,9 @@ sub import {
   #warnings->import::into($target);
   warnings->import::into($target, FATAL => 'all'); # blowing up a test is ok
 
+  #As of perl 5.39.8 multiple 'use' specifying Perl version is deprecated
   #use 5.010;  # say, state
-  use 5.011;  # cpantester gets warning that 5.11 is the minimum acceptable
+  #use 5.011;  # cpantester gets warning that 5.11 is the minimum acceptable
   use 5.018;  # lexical_subs
   require feature;
   # Perl 5.18.0 seems to require the "no experimental..." before the "use feature"
@@ -151,7 +170,14 @@ sub import {
   require Guard;
   Guard->import::into($target, qw(scope_guard guard));
 
-  use Data::Dumper::Interp 6.006 ();
+  use Data::Dumper::Interp 7.009 ();
+  unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
+    # Unless we are testing DDI
+    no warnings 'once';
+    # Don't follow overloads e.g. stringify
+    $Data::Dumper::Interp::Objects = {overloads => "ignore"};
+  }
+
   unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
     # unless we are testing DDI
     Data::Dumper::Interp->import::into($target,
